@@ -29,8 +29,6 @@
 Script for installing rdmanifest-described resources
 """
 
-from __future__ import print_function
-
 import os
 import sys
 from optparse import OptionParser
@@ -42,10 +40,10 @@ NAME = 'rosdep-source'
 
 
 def install_main():
-    parser = OptionParser(usage="usage: %prog install <rdmanifest-url>", prog=NAME)
+    parser = OptionParser(usage='usage: %prog install <rdmanifest-url>', prog=NAME)
     options, args = parser.parse_args()
     if len(args) != 2:
-        parser.error("please specify one and only one rdmanifest url")
+        parser.error('please specify one and only one rdmanifest url')
     if args[0] != 'install':
         parser.error("currently only support the 'install' command")
     rdmanifest_url = args[1]
@@ -55,5 +53,5 @@ def install_main():
         else:
             source.install_from_url(rdmanifest_url)
     except InstallFailed as e:
-        print("ERROR: installation failed:\n%s" % e, file=sys.stderr)
+        print('ERROR: installation failed:\n%s' % e, file=sys.stderr)
         sys.exit(1)
