@@ -34,11 +34,11 @@ except ImportError:
     from io import StringIO
 
 import rospkg
-import rospkg.os_detect
 
 import unittest
 from unittest.mock import DEFAULT, patch
 
+from rosdep2 import create_default_installer_context
 from rosdep2 import main
 from rosdep2.ament_packages import AMENT_PREFIX_PATH_ENV_VAR
 from rosdep2.main import rosdep_main
@@ -132,8 +132,8 @@ class TestRosdepMain(unittest.TestCase):
             stdout, stderr = b
             assert stdout.getvalue().strip() == 'All system dependencies have been satisfied', stdout.getvalue()
         try:
-            osd = rospkg.os_detect.OsDetect()
-            override = '%s:%s' % (osd.get_name(), osd.get_codename())
+            context = create_default_installer_context()
+            override = '%s:%s' % context.get_os_name_and_version()
             with fakeout() as b:
                 rosdep_main(['check', 'python_dep', '--os', override] + cmd_extras)
                 stdout, stderr = b
@@ -280,6 +280,38 @@ class TestRosdepMain(unittest.TestCase):
         except SystemExit:
             pass
 
+    def test_search(self):
+        sources_cache = get_cache_dir()
+        cmd_extras = ['-c', sources_cache]
+
+        try:
+            with fakeout() as b:
+                rosdep_main(['search', 'curl', '--os=debian:squeeze'] + cmd_extras)
+                stdout, stderr = b
+                assert 'Closest keys' in stdout.getvalue(), stdout.getvalue()
+                assert 'curl' in stdout.getvalue(), stdout.getvalue()
+                assert 'Closest packages' not in stdout.getvalue(), stdout.getvalue()
+                assert not stderr.getvalue(), stderr.getvalue()
+            with fakeout() as b:
+                rosdep_main(['search', 'libeigen3-dev', '--os=ubuntu:noble'] + cmd_extras)
+                stdout, stderr = b
+                assert 'Closest keys' not in stdout.getvalue(), stdout.getvalue()
+                assert 'Closest packages' in stdout.getvalue(), stdout.getvalue()
+                assert 'eigen:' in stdout.getvalue(), stdout.getvalue()
+                assert not stderr.getvalue(), stderr.getvalue()
+        except SystemExit:
+            assert False, 'system exit occurred'
+        try:
+            rosdep_main(['search', 'libeigen3-dev', '--os=debian:squeeze'] + cmd_extras)
+            assert False, 'system exit should have occurred'
+        except SystemExit:
+            pass
+        try:
+            rosdep_main(['search', 'nonexistent'] + cmd_extras + ['-i'])
+            assert False, 'system exit should have occurred'
+        except SystemExit:
+            pass
+
     @patch('rosdep2.main.install_opener')
     @patch('rosdep2.main.build_opener')
     @patch('rosdep2.main.HTTPBasicAuthHandler')
