@@ -29,11 +29,8 @@
 
 import os
 import yaml
+from unittest.mock import Mock
 
-try:
-    from unittest.mock import Mock
-except ImportError:
-    from mock import Mock
 from rospkg import RosPack, RosStack
 
 
