@@ -31,6 +31,9 @@ import os
 import pytest
 import yaml
 
+from .conftest import path_to_url
+
+
 rep122_install_command = """#!/bin/bash
 set -o errexit
 mkdir -p build
@@ -195,7 +198,7 @@ def test_SourceInstaller_resolve():
     from rosdep2.platforms.source import SourceInstaller, InvalidData
     test_dir = get_test_dir()
 
-    url = 'file://%s' % os.path.join(test_dir, 'rep112-example.rdmanifest')
+    url = path_to_url(os.path.join(test_dir, 'rep112-example.rdmanifest'))
     md5sum_good = REP112_MD5SUM
     md5sum_bad = 'fake'
 
@@ -212,7 +215,7 @@ def test_SourceInstaller_resolve():
         pass
     resolved = installer.resolve(dict(uri=url, md5sum=md5sum_good))
 
-    assert type(resolved) == list
+    assert type(resolved) is list
     assert len(resolved) == 1
     # test for reinstall (to check the depends in rdmanifest)
     dependencies = installer.get_depends(dict(uri=url, md5sum=md5sum_good))
@@ -224,7 +227,7 @@ def test_SourceInstaller_resolve():
 
     # test again to activate caching
     resolved = installer.resolve(dict(uri=url, md5sum=md5sum_good))
-    assert type(resolved) == list, 'Cache should also return a list'
+    assert type(resolved) is list, 'Cache should also return a list'
     assert len(resolved) == 1
     resolved = resolved[0]
     assert resolved.install_command == rep122_install_command
@@ -256,7 +259,7 @@ def test_fetch_file():
         expected = f.read()
 
     from rosdep2.platforms.source import fetch_file
-    url = 'file://%s' % os.path.join(test_dir, 'rep112-example.rdmanifest')
+    url = path_to_url(os.path.join(test_dir, 'rep112-example.rdmanifest'))
     contents, error = fetch_file(url, REP112_MD5SUM)
     assert not error
     assert contents == expected
@@ -276,7 +279,7 @@ def test_download_rdmanifest():
         expected = yaml.safe_load(f)
 
     from rosdep2.platforms.source import download_rdmanifest, DownloadFailed
-    url = 'file://%s' % os.path.join(test_dir, 'rep112-example.rdmanifest')
+    url = path_to_url(os.path.join(test_dir, 'rep112-example.rdmanifest'))
     contents, download_url = download_rdmanifest(url, REP112_MD5SUM)
     assert contents == expected
     assert download_url == url
